==> hinemos_src-2.4.3.tar.gz: Hinemos_src-2.4.3/Performance/src/com/clustercontrol/performance/view/action/ExportCollectedDataAction.java <==
/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 */

package com.clustercontrol.performance.view.action;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PlatformUI;

import com.clustercontrol.performance.action.RecordController;
import com.clustercontrol.performance.dialog.ExportDialog;
import com.clustercontrol.performance.util.Messages;
import com.clustercontrol.performance.view.CurrentListView;
import com.clustercontrol.performanceMGR.bean.CollectorProperty;

/**
 * 収集済みデータのエクスポートを行うアクションクラス
 * 
 * @version 1.0
 * @since 1.0
 */
public class ExportCollectedDataAction implements IViewActionDelegate {
    public static final String ID = "com.clustercontrol.performance.view.action.ExportCollectedDataAction";
	
    private static ExportDialog exportDialog;

    private IViewPart viewPart; // ビュー

    /**
     * ビューを保持します。ワークベンチにロードされた際に呼ばれます。
     * 
     * @param view ビューのインスタンス
     * 
     * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
     */
    public void init(IViewPart view) {
        this.viewPart = view;
    }

    /**
     * 性能[収集データ]ビューで選択されている収集の性能値をエクスポートします。
     * 
     * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
     */
    public void run(IAction action) {
        /*
         * 呼び出し元のViewを持ってきます。
         */
        IWorkbenchPage page = PlatformUI.getWorkbench()
                .getActiveWorkbenchWindow().getActivePage();
        CurrentListView listView = (CurrentListView) page
                .findView(Messages.getString("VIEW_CURRENT_LIST"));

        /*
         * テーブルで選ばれている収集のIDを取得します。
         */
        String collectorID = listView.getSelectedID();

        if (collectorID != null) {
    		// アクセス権なしの場合、エラーダイアログを表示する
        	if(!RecordController.getInstance().checkPermissionRead()){
        		MessageDialog.openInformation(null, com.clustercontrol.util.Messages.getString("message"),
        				com.clustercontrol.util.Messages.getString("message.accesscontrol.16"));
        		return;
        	}
        	
            // マネージャからプロパティ情報を収集する
            RecordController controller = RecordController.getInstance();
            // マネージャとの接続に失敗した場合はエラーダイアログを表示
            if (controller == null) {
                MessageDialog.openError(this.viewPart.getSite().getShell(),
                        Messages.getString("MESSAGE_0020"),  // "確認"
                        Messages.getString("CONNECTION_ERROR_MESSAGE"));
                return;
            }

            // 削除ロックをかける
            controller.lock(collectorID);
            
            CollectorProperty property = controller
                    .getCollectorProperty(collectorID);
            // 収集定義を取得できなかった場合はエラーダイアログを表示
            if (property == null) {
                MessageDialog.openError(this.viewPart.getSite().getShell(),
                        Messages.getString("MESSAGE_0020"),  // "確認"
                        Messages.getString("GET_PROPERTY_ERROR_MESSAGE"));
                return;
            }

            // 収集回数が0以下の場合はエクスポートすることができない
            if (property.getCollectorData().getCount() <= 0) {
                MessageDialog
                        .openError(
                                this.viewPart.getSite().getShell(),
                                Messages.getString("MESSAGE_0020"),  // "確認"
                                Messages.getString("INSUFFICIENT_DATA"));
                return;
            }

            Shell shell = new Shell();
            exportDialog = new ExportDialog(shell);
            exportDialog.setCollectorProperty(property);
            exportDialog.open();

            // 削除ロックを解除
            controller.unlock();
        } else {

            String msg = Messages.getString("MESSAGE_0014");
            MessageDialog.openError(null,
                    Messages.getString("ERROR_IN_JP"), msg);
        }
    }

    public void selectionChanged(IAction action, ISelection selection) {

    }

}

==> hinemos_src-3.1.2.tar.gz: Hinemos_src-3.1.2/Performance/src/com/clustercontrol/performance/view/action/ExportCollectedDataAction.java <==
/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 */

package com.clustercontrol.performance.view.action;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PlatformUI;

import com.clustercontrol.performance.action.RecordController;
import com.clustercontrol.performance.dialog.ExportDialog;
import com.clustercontrol.performance.util.Messages;
import com.clustercontrol.performance.view.CurrentListView;
import com.clustercontrol.performance.bean.CollectorProperty;

/**
 * 収集済みデータのエクスポートを行うアクションクラス
 * 
 * @version 1.0
 * @since 1.0
 */
public class ExportCollectedDataAction implements IViewActionDelegate {
    public static final String ID = "com.clustercontrol.performance.view.action.ExportCollectedDataAction";
	
    private static ExportDialog exportDialog;

    private IViewPart viewPart; // ビュー

    /**
     * ビューを保持します。ワークベンチにロードされた際に呼ばれます。
     * 
     * @param view ビューのインスタンス
     * 
     * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
     */
    public void init(IViewPart view) {
        this.viewPart = view;
    }

    /**
     * 性能[収集データ]ビューで選択されている収集の性能値をエクスポートします。
     * 
     * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
     */
    public void run(IAction action) {
        /*
         * 呼び出し元のViewを持ってきます。
         */
        IWorkbenchPage page = PlatformUI.getWorkbench()
                .getActiveWorkbenchWindow().getActivePage();
        CurrentListView listView = (CurrentListView) page
                .findView(CurrentListView.ID);

        /*
         * テーブルで選ばれている収集のIDを取得します。
         */
        String collectorID = listView.getSelectedID();

        if (collectorID != null) {
    		// アクセス権なしの場合、エラーダイアログを表示する
        	if(!RecordController.getInstance().checkPermissionRead()){
        		MessageDialog.openInformation(null, com.clustercontrol.util.Messages.getString("message"),
        				com.clustercontrol.util.Messages.getString("message.accesscontrol.16"));
        		return;
        	}
        	
            // マネージャからプロパティ情報を収集する
            RecordController controller = RecordController.getInstance();
            // マネージャとの接続に失敗した場合はエラーダイアログを表示
            if (controller == null) {
                MessageDialog.openError(this.viewPart.getSite().getShell(),
                        Messages.getString("MESSAGE_0020"),  // "確認"
                        Messages.getString("CONNECTION_ERROR_MESSAGE"));
                return;
            }

            // 削除ロックをかける
            controller.lock(collectorID);
            
            CollectorProperty property = controller
                    .getCollectorProperty(collectorID);
            // 収集定義を取得できなかった場合はエラーダイアログを表示
            if (property == null) {
                MessageDialog.openError(this.viewPart.getSite().getShell(),
                        Messages.getString("MESSAGE_0020"),  // "確認"
                        Messages.getString("GET_PROPERTY_ERROR_MESSAGE"));
                return;
            }

            // 収集回数が0以下の場合はエクスポートすることができない
            if (property.getCollectorData().getCount() <= 0) {
                MessageDialog
                        .openError(
                                this.viewPart.getSite().getShell(),
                                Messages.getString("MESSAGE_0020"),  // "確認"
                                Messages.getString("INSUFFICIENT_DATA"));
                return;
            }

            Shell shell = new Shell();
            exportDialog = new ExportDialog(shell);
            exportDialog.setCollectorProperty(property);
            exportDialog.open();

            // 削除ロックを解除
            controller.unlock();
        } else {

            String msg = Messages.getString("MESSAGE_0014");
            MessageDialog.openError(null,
                    Messages.getString("ERROR_IN_JP"), msg);
        }
    }

    public void selectionChanged(IAction action, ISelection selection) {

    }

}
